@@ -65,8 +65,11 @@ MainWindow::MainWindow()
 			global_flags.interpolation_quality = settings.interpolation_quality() - 1;
 		}
 	}
-	if (!global_flags.cue_point_padding_set) {
-		global_flags.cue_point_padding_seconds = settings.cue_point_padding_seconds();  // Default 0 is fine.
+	if (!global_flags.cue_in_point_padding_set) {
+		global_flags.cue_in_point_padding_seconds = settings.cue_in_point_padding_seconds();  // Default 0 is fine.
+	}
+	if (!global_flags.cue_out_point_padding_set) {
+		global_flags.cue_out_point_padding_seconds = settings.cue_out_point_padding_seconds();  // Default 0 is fine.
 	}
 	if (global_flags.interpolation_quality == 0) {
 		// Allocate something just for simplicity; we won't be using it
@@ -115,27 +118,49 @@ MainWindow::MainWindow()
 	connect(ui->quality_3_action, &QAction::toggled, bind(&MainWindow::quality_toggled, this, 3, _1));
 	connect(ui->quality_4_action, &QAction::toggled, bind(&MainWindow::quality_toggled, this, 4, _1));
 
-	// The cue point padding group.
-	QActionGroup *padding_group = new QActionGroup(ui->interpolation_menu);
-	padding_group->addAction(ui->padding_0_action);
-	padding_group->addAction(ui->padding_1_action);
-	padding_group->addAction(ui->padding_2_action);
-	padding_group->addAction(ui->padding_5_action);
-	if (global_flags.cue_point_padding_seconds <= 1e-3) {
-		ui->padding_0_action->setChecked(true);
-	} else if (fabs(global_flags.cue_point_padding_seconds - 1.0) < 1e-3) {
-		ui->padding_1_action->setChecked(true);
-	} else if (fabs(global_flags.cue_point_padding_seconds - 2.0) < 1e-3) {
-		ui->padding_2_action->setChecked(true);
-	} else if (fabs(global_flags.cue_point_padding_seconds - 5.0) < 1e-3) {
-		ui->padding_5_action->setChecked(true);
+	// The cue-in point padding group.
+	QActionGroup *in_padding_group = new QActionGroup(ui->in_padding_menu);
+	in_padding_group->addAction(ui->in_padding_0_action);
+	in_padding_group->addAction(ui->in_padding_1_action);
+	in_padding_group->addAction(ui->in_padding_2_action);
+	in_padding_group->addAction(ui->in_padding_5_action);
+	if (global_flags.cue_in_point_padding_seconds <= 1e-3) {
+		ui->in_padding_0_action->setChecked(true);
+	} else if (fabs(global_flags.cue_in_point_padding_seconds - 1.0) < 1e-3) {
+		ui->in_padding_1_action->setChecked(true);
+	} else if (fabs(global_flags.cue_in_point_padding_seconds - 2.0) < 1e-3) {
+		ui->in_padding_2_action->setChecked(true);
+	} else if (fabs(global_flags.cue_in_point_padding_seconds - 5.0) < 1e-3) {
+		ui->in_padding_5_action->setChecked(true);
 	} else {
 		// Nothing to check, which is fine.
 	}
-	connect(ui->padding_0_action, &QAction::toggled, bind(&MainWindow::padding_toggled, this, 0.0, _1));
-	connect(ui->padding_1_action, &QAction::toggled, bind(&MainWindow::padding_toggled, this, 1.0, _1));
-	connect(ui->padding_2_action, &QAction::toggled, bind(&MainWindow::padding_toggled, this, 2.0, _1));
-	connect(ui->padding_5_action, &QAction::toggled, bind(&MainWindow::padding_toggled, this, 5.0, _1));
+	connect(ui->in_padding_0_action, &QAction::toggled, bind(&MainWindow::in_padding_toggled, this, 0.0, _1));
+	connect(ui->in_padding_1_action, &QAction::toggled, bind(&MainWindow::in_padding_toggled, this, 1.0, _1));
+	connect(ui->in_padding_2_action, &QAction::toggled, bind(&MainWindow::in_padding_toggled, this, 2.0, _1));
+	connect(ui->in_padding_5_action, &QAction::toggled, bind(&MainWindow::in_padding_toggled, this, 5.0, _1));
+
+	// Same for the cue-out padding.
+	QActionGroup *out_padding_group = new QActionGroup(ui->out_padding_menu);
+	out_padding_group->addAction(ui->out_padding_0_action);
+	out_padding_group->addAction(ui->out_padding_1_action);
+	out_padding_group->addAction(ui->out_padding_2_action);
+	out_padding_group->addAction(ui->out_padding_5_action);
+	if (global_flags.cue_out_point_padding_seconds <= 1e-3) {
+		ui->out_padding_0_action->setChecked(true);
+	} else if (fabs(global_flags.cue_out_point_padding_seconds - 1.0) < 1e-3) {
+		ui->out_padding_1_action->setChecked(true);
+	} else if (fabs(global_flags.cue_out_point_padding_seconds - 2.0) < 1e-3) {
+		ui->out_padding_2_action->setChecked(true);
+	} else if (fabs(global_flags.cue_out_point_padding_seconds - 5.0) < 1e-3) {
+		ui->out_padding_5_action->setChecked(true);
+	} else {
+		// Nothing to check, which is fine.
+	}
+	connect(ui->out_padding_0_action, &QAction::toggled, bind(&MainWindow::out_padding_toggled, this, 0.0, _1));
+	connect(ui->out_padding_1_action, &QAction::toggled, bind(&MainWindow::out_padding_toggled, this, 1.0, _1));
+	connect(ui->out_padding_2_action, &QAction::toggled, bind(&MainWindow::out_padding_toggled, this, 2.0, _1));
+	connect(ui->out_padding_5_action, &QAction::toggled, bind(&MainWindow::out_padding_toggled, this, 5.0, _1));
 
 	global_disk_space_estimator = new DiskSpaceEstimator(bind(&MainWindow::report_disk_space, this, _1, _2));
 	disk_free_label = new QLabel(this);
@@ -180,6 +205,10 @@ MainWindow::MainWindow()
 	connect(play, &QShortcut::activated, ui->play_btn, &QPushButton::click);
 	connect(ui->play_btn, &QPushButton::clicked, this, &MainWindow::play_clicked);
 
+	QShortcut *next = new QShortcut(QKeySequence(Qt::Key_N), this);
+	connect(next, &QShortcut::activated, ui->next_btn, &QPushButton::click);
+	connect(ui->next_btn, &QPushButton::clicked, this, &MainWindow::next_clicked);
+
 	connect(ui->stop_btn, &QPushButton::clicked, this, &MainWindow::stop_clicked);
 	ui->stop_btn->setEnabled(false);
 
@@ -217,7 +246,7 @@ MainWindow::MainWindow()
 			live_player_done();
 		});
 	});
-	live_player->set_progress_callback([this](const map<uint64_t, double> &progress, double time_remaining) {
+	live_player->set_progress_callback([this](const map<uint64_t, double> &progress, TimeRemaining time_remaining) {
 		post_to_main_thread([this, progress, time_remaining] {
 			live_player_clip_progress(progress, time_remaining);
 		});
@@ -272,9 +301,17 @@ void MainWindow::change_num_cameras()
 {
 	assert(num_cameras >= displays.size());  // We only add, never remove.
 
+	// Make new entries to hide the displays.
+	for (unsigned i = displays.size(); i < num_cameras; ++i) {
+		char title[256];
+		snprintf(title, sizeof(title), "Camera %u", i + 1);
+		QAction *hide_action = ui->hide_camera_menu->addAction(title);
+		hide_action->setCheckable(true);
+		hide_action->setChecked(false);
+		connect(hide_action, &QAction::toggled, bind(&MainWindow::hide_camera_toggled, this, i, _1));
+	}
+
 	// Make new display rows.
-	unsigned display_rows = (num_cameras + 1) / 2;
-	ui->video_displays->setStretch(1, display_rows);
 	for (unsigned i = displays.size(); i < num_cameras; ++i) {
 		QFrame *frame = new QFrame(this);
 		frame->setAutoFillBackground(true);
@@ -287,7 +324,6 @@ void MainWindow::change_num_cameras()
 		display->setAutoFillBackground(true);
 		layout->addWidget(display);
 
-		ui->input_displays->addWidget(frame, i / 2, i % 2);
 		display->set_overlay(to_string(i + 1));
 
 		QPushButton *preview_btn = new QPushButton(this);
@@ -295,7 +331,7 @@ void MainWindow::change_num_cameras()
 		preview_btn->setText(QString::fromStdString(to_string(i + 1)));
 		ui->preview_layout->addWidget(preview_btn);
 
-		displays.emplace_back(FrameAndDisplay{ frame, display, preview_btn });
+		displays.emplace_back(FrameAndDisplay{ frame, display, preview_btn, /*hidden=*/false });
 
 		connect(display, &JPEGFrameView::clicked, preview_btn, &QPushButton::click);
 		QShortcut *shortcut = new QShortcut(QKeySequence(Qt::Key_1 + i), this);
@@ -303,6 +339,7 @@ void MainWindow::change_num_cameras()
 
 		connect(preview_btn, &QPushButton::clicked, [this, i] { preview_angle_clicked(i); });
 	}
+	relayout_displays();
 
 	cliplist_clips->change_num_cameras(num_cameras);
 	playlist_clips->change_num_cameras(num_cameras);
@@ -310,6 +347,28 @@ void MainWindow::change_num_cameras()
 	QMetaObject::invokeMethod(this, "relayout", Qt::QueuedConnection);
 }
 
+void MainWindow::relayout_displays()
+{
+	while (ui->input_displays->count() > 0) {
+		QLayoutItem *item = ui->input_displays->takeAt(0);
+		ui->input_displays->removeWidget(item->widget());
+	}
+
+	unsigned cell_idx = 0;
+	for (unsigned i = 0; i < displays.size(); ++i) {
+		if (displays[i].hidden) {
+			displays[i].frame->setVisible(false);
+		} else {
+			displays[i].frame->setVisible(true);
+			ui->input_displays->addWidget(displays[i].frame, cell_idx / 2, cell_idx % 2);
+			++cell_idx;
+		}
+	}
+	ui->video_displays->setStretch(1, (cell_idx + 1) / 2);
+
+	QMetaObject::invokeMethod(this, "relayout", Qt::QueuedConnection);
+}
+
 MainWindow::~MainWindow()
 {
 	// We don't have a context to release Player's OpenGL resources in here,
@@ -324,7 +383,7 @@ void MainWindow::cue_in_clicked()
 		cliplist_clips->mutable_back()->pts_in = current_pts;
 	} else {
 		Clip clip;
-		clip.pts_in = max<int64_t>(current_pts - lrint(global_flags.cue_point_padding_seconds * TIMEBASE), 0);
+		clip.pts_in = max<int64_t>(current_pts - lrint(global_flags.cue_in_point_padding_seconds * TIMEBASE), 0);
 		cliplist_clips->add_clip(clip);
 		playlist_selection_changed();
 	}
@@ -343,7 +402,7 @@ void MainWindow::cue_out_clicked()
 		return;
 	}
 
-	cliplist_clips->mutable_back()->pts_out = current_pts + lrint(global_flags.cue_point_padding_seconds * TIMEBASE);
+	cliplist_clips->mutable_back()->pts_out = current_pts + lrint(global_flags.cue_out_point_padding_seconds * TIMEBASE);
 
 	// Select the item so that we can jog it.
 	ui->clip_list->setFocus();
@@ -365,11 +424,9 @@ void MainWindow::queue_clicked()
 	if (!selected->hasSelection()) {
 		Clip clip = *cliplist_clips->back();
 		clip.stream_idx = 0;
-		if (clip.pts_out != -1) {
-			playlist_clips->add_clip(clip);
-			playlist_selection_changed();
-			ui->playlist->scrollToBottom();
-		}
+		playlist_clips->add_clip(clip);
+		playlist_selection_changed();
+		ui->playlist->scrollToBottom();
 		return;
 	}
 
@@ -381,15 +438,13 @@ void MainWindow::queue_clicked()
 		clip.stream_idx = ui->preview_display->get_stream_idx();
 	}
 
-	if (clip.pts_out != -1) {
-		playlist_clips->add_clip(clip);
-		playlist_selection_changed();
-		ui->playlist->scrollToBottom();
-		if (!ui->playlist->selectionModel()->hasSelection()) {
-			// TODO: Figure out why this doesn't always seem to actually select the row.
-			QModelIndex bottom = playlist_clips->index(playlist_clips->size() - 1, 0);
-			ui->playlist->setCurrentIndex(bottom);
-		}
+	playlist_clips->add_clip(clip);
+	playlist_selection_changed();
+	ui->playlist->scrollToBottom();
+	if (!ui->playlist->selectionModel()->hasSelection()) {
+		// TODO: Figure out why this doesn't always seem to actually select the row.
+		QModelIndex bottom = playlist_clips->index(playlist_clips->size() - 1, 0);
+		ui->playlist->setCurrentIndex(bottom);
 	}
 }
 
@@ -428,6 +483,9 @@ void MainWindow::preview_clicked()
 	} else {
 		clip.stream_idx = ui->preview_display->get_stream_idx();
 	}
+	if (clip.pts_out == -1) {
+		clip.pts_out = clip.pts_in + int64_t(TIMEBASE) * 86400 * 7;  // One week; effectively infinite, but without overflow issues.
+	}
 	preview_player->play(clip);
 	preview_playing = true;
 	enable_or_disable_preview_button();
@@ -609,7 +667,8 @@ void MainWindow::save_settings()
 {
 	SettingsProto settings;
 	settings.set_interpolation_quality(global_flags.interpolation_quality + 1);
-	settings.set_cue_point_padding_seconds(global_flags.cue_point_padding_seconds);
+	settings.set_cue_in_point_padding_seconds(global_flags.cue_in_point_padding_seconds);
+	settings.set_cue_out_point_padding_seconds(global_flags.cue_out_point_padding_seconds);
 	db.store_settings(settings);
 }
 
@@ -628,7 +687,11 @@ void MainWindow::play_clicked()
 
 	vector<ClipWithID> clips;
 	for (unsigned row = start_row; row < playlist_clips->size(); ++row) {
-		clips.emplace_back(*playlist_clips->clip_with_id(row));
+		ClipWithID clip = *playlist_clips->clip_with_id(row);
+		if (clip.clip.pts_out == -1) {
+			clip.clip.pts_out = clip.clip.pts_in + int64_t(TIMEBASE) * 86400 * 7;  // One week; effectively infinite, but without overflow issues.
+		}
+		clips.emplace_back(clip);
 	}
 	live_player->play(clips);
 	playlist_clips->set_progress({ { start_row, 0.0f } });
@@ -637,6 +700,11 @@ void MainWindow::play_clicked()
 	playlist_selection_changed();
 }
 
+void MainWindow::next_clicked()
+{
+	live_player->skip_to_next();
+}
+
 void MainWindow::stop_clicked()
 {
 	Clip fake_clip;
@@ -678,7 +746,7 @@ void MainWindow::live_player_done()
 	playlist_selection_changed();
 }
 
-void MainWindow::live_player_clip_progress(const map<uint64_t, double> &progress, double time_remaining)
+void MainWindow::live_player_clip_progress(const map<uint64_t, double> &progress, TimeRemaining time_remaining)
 {
 	playlist_clips->set_progress(progress);
 	set_output_status(format_duration(time_remaining) + " left");
@@ -707,6 +775,7 @@ bool MainWindow::eventFilter(QObject *watched, QEvent *event)
 
 	if (event->type() == QEvent::FocusIn || event->type() == QEvent::FocusOut) {
 		enable_or_disable_preview_button();
+		playlist_selection_changed();
 		hidden_jog_column = -1;
 	}
 
@@ -775,6 +844,11 @@ bool MainWindow::eventFilter(QObject *watched, QEvent *event)
 		if (mouse->modifiers() & Qt::KeyboardModifier::ShiftModifier) {
 			scrub_sensitivity *= 10;
 			wheel_sensitivity *= 10;
+			if (mouse->modifiers() & Qt::KeyboardModifier::ControlModifier) {
+				// Ctrl+Shift is a super-modifier, meant only for things like “go back two hours”.
+				scrub_sensitivity *= 100;
+				wheel_sensitivity *= 100;
+			}
 		}
 		if (mouse->modifiers() & Qt::KeyboardModifier::AltModifier) {  // Note: Shift + Alt cancel each other out.
 			scrub_sensitivity /= 10;
@@ -830,6 +904,11 @@ bool MainWindow::eventFilter(QObject *watched, QEvent *event)
 		if (wheel->modifiers() & Qt::KeyboardModifier::ShiftModifier) {
 			scrub_sensitivity *= 10;
 			wheel_sensitivity *= 10;
+			if (wheel->modifiers() & Qt::KeyboardModifier::ControlModifier) {
+				// Ctrl+Shift is a super-modifier, meant only for things like “go back two hours”.
+				scrub_sensitivity *= 100;
+				wheel_sensitivity *= 100;
+			}
 		}
 		if (wheel->modifiers() & Qt::KeyboardModifier::AltModifier) {  // Note: Shift + Alt cancel each other out.
 			scrub_sensitivity /= 10;
@@ -915,6 +994,19 @@ void MainWindow::playlist_selection_changed()
 		any_selected && selected->selectedRows().back().row() < int(playlist_clips->size()) - 1);
 
 	ui->play_btn->setEnabled(any_selected);
+	ui->next_btn->setEnabled(ui->stop_btn->isEnabled());  // TODO: Perhaps not if we're on the last clip?
+	midi_mapper.set_next_ready(ui->next_btn->isEnabled() ? MIDIMapper::On : MIDIMapper::Off);
+
+	// NOTE: The hidden button is still reachable by keyboard or MIDI.
+	if (any_selected) {
+		ui->play_btn->setVisible(true);
+	} else if (ui->stop_btn->isEnabled()) {  // Playing.
+		ui->play_btn->setVisible(false);
+	} else {
+		ui->play_btn->setVisible(true);
+	}
+	ui->next_btn->setVisible(!ui->play_btn->isVisible());
+
 	if (ui->stop_btn->isEnabled()) {  // Playing.
 		midi_mapper.set_play_enabled(MIDIMapper::On);
 	} else if (any_selected) {
@@ -930,7 +1022,7 @@ void MainWindow::playlist_selection_changed()
 		for (size_t row = selected->selectedRows().front().row(); row < playlist_clips->size(); ++row) {
 			clips.emplace_back(*playlist_clips->clip_with_id(row));
 		}
-		double remaining = compute_total_time(clips);
+		TimeRemaining remaining = compute_total_time(clips);
 		set_output_status(format_duration(remaining) + " ready");
 	}
 }
@@ -1130,15 +1222,30 @@ void MainWindow::quality_toggled(int quality, bool checked)
 	save_settings();
 }
 
-void MainWindow::padding_toggled(double seconds, bool checked)
+void MainWindow::in_padding_toggled(double seconds, bool checked)
 {
 	if (!checked) {
 		return;
 	}
-	global_flags.cue_point_padding_seconds = seconds;
+	global_flags.cue_in_point_padding_seconds = seconds;
 	save_settings();
 }
 
+void MainWindow::out_padding_toggled(double seconds, bool checked)
+{
+	if (!checked) {
+		return;
+	}
+	global_flags.cue_out_point_padding_seconds = seconds;
+	save_settings();
+}
+
+void MainWindow::hide_camera_toggled(unsigned camera_idx, bool checked)
+{
+	displays[camera_idx].hidden = checked;
+	relayout_displays();
+}
+
 void MainWindow::highlight_camera_input(int stream_idx)
 {
 	for (unsigned i = 0; i < num_cameras; ++i) {
@@ -1185,15 +1292,7 @@ void MainWindow::enable_or_disable_queue_button()
 	if (cliplist_clips->empty()) {
 		enabled = false;
 	} else {
-		QItemSelectionModel *selected = ui->clip_list->selectionModel();
-		if (!selected->hasSelection()) {
-			Clip clip = *cliplist_clips->back();
-			enabled = clip.pts_out != -1;
-		} else {
-			QModelIndex index = selected->currentIndex();
-			Clip clip = *cliplist_clips->clip(index.row());
-			enabled = clip.pts_out != -1;
-		}
+		enabled = true;
 	}
 
 	ui->queue_btn->setEnabled(enabled);
@@ -1253,6 +1352,13 @@ void MainWindow::play()
 	});
 }
 
+void MainWindow::next()
+{
+	post_to_main_thread([this] {
+		next_clicked();
+	});
+}
+
 void MainWindow::toggle_lock()
 {
 	post_to_main_thread([this] {
