@@ -46,6 +46,8 @@ vector<MIDIMappingDialog::Control> buttons = {
 	                  MIDIMappingProto::kQueueBankFieldNumber },
 	{ "Play",         MIDIMappingProto::kPlayFieldNumber,
 	                  MIDIMappingProto::kPlayBankFieldNumber },
+	{ "Next",         MIDIMappingProto::kNextFieldNumber,
+	                  MIDIMappingProto::kNextButtonBankFieldNumber },
 	{ "Lock master speed", MIDIMappingProto::kToggleLockFieldNumber,
 	                  MIDIMappingProto::kToggleLockBankFieldNumber },
 	{ "Cue in",       MIDIMappingProto::kCueInFieldNumber,
@@ -66,6 +68,7 @@ vector<MIDIMappingDialog::Control> button_lights = {
         { "Queue button enabled", MIDIMappingProto::kQueueEnabledFieldNumber, 0 },
         { "Playing",              MIDIMappingProto::kPlayingFieldNumber, 0 },
         { "Play ready",           MIDIMappingProto::kPlayReadyFieldNumber, 0 },
+        { "Next ready",           MIDIMappingProto::kNextReadyFieldNumber, 0 },
         { "Master speed locked",  MIDIMappingProto::kLockedFieldNumber, 0 },
         { "Master speed locked (blinking)",
 	                          MIDIMappingProto::kLockedBlinkingFieldNumber, 0 },
