@@ -114,8 +114,6 @@ private:
 
 		// For original frames only. Made move-only so we know explicitly
 		// we don't copy these ~200 kB files around inadvertedly.
-		//
-		// TODO: Consider using vector<uint8_t> instead, so we save one copy.
 		std::unique_ptr<std::string> encoded_jpeg;
 
 		// For everything except original frames.
@@ -160,7 +158,7 @@ private:
 	GLuint last_flow_tex = 0;
 	FrameOnDisk last_frame1, last_frame2;
 
-	std::vector<uint8_t> last_frame;
+	std::string last_frame;
 };
 
 #endif  // !defined(_VIDEO_STREAM_H)
