@@ -54,9 +54,9 @@ public:
 	// the lock wasn't successfully taken; if so, you should simply try again.
 	// (This is to avoid a deadlock where a card hangs on the mutex in add_audio()
 	// while we are trying to shut it down from another thread that also holds
-	// the mutex.) frame_length is in TIMEBASE units.
-	bool add_audio(DeviceSpec device_spec, const uint8_t *data, unsigned num_samples, bmusb::AudioFormat audio_format, int64_t frame_length, std::chrono::steady_clock::time_point frame_time);
-	bool add_silence(DeviceSpec device_spec, unsigned samples_per_frame, unsigned num_frames, int64_t frame_length);
+	// the mutex.)
+	bool add_audio(DeviceSpec device_spec, const uint8_t *data, unsigned num_samples, bmusb::AudioFormat audio_format, std::chrono::steady_clock::time_point frame_time);
+	bool add_silence(DeviceSpec device_spec, unsigned samples_per_frame, unsigned num_frames);
 
 	// If a given device is offline for whatever reason and cannot deliver audio
 	// (by means of add_audio() or add_silence()), you can call put it in silence mode,
