@@ -451,6 +451,10 @@ bool FFmpegCapture::play_video(const string &pathname)
 		if (process_queued_commands(format_ctx.get(), pathname, last_modified, /*rewound=*/nullptr)) {
 			return true;
 		}
+		if (should_interrupt.load()) {
+			// Check as a failsafe, so that we don't need to rely on avio if we don't have to.
+			return false;
+		}
 		UniqueFrame audio_frame = audio_frame_allocator->alloc_frame();
 		AudioFormat audio_format;
 
@@ -463,6 +467,11 @@ bool FFmpegCapture::play_video(const string &pathname)
 		}
 		if (frame == nullptr) {
 			// EOF. Loop back to the start if we can.
+			if (format_ctx->pb != nullptr && format_ctx->pb->seekable == 0) {
+				// Not seekable (but seemingly, sometimes av_seek_frame() would return 0 anyway,
+				// so don't try).
+				return true;
+			}
 			if (av_seek_frame(format_ctx.get(), /*stream_index=*/-1, /*timestamp=*/0, /*flags=*/0) < 0) {
 				fprintf(stderr, "%s: Rewind failed, not looping.\n", pathname.c_str());
 				return true;
@@ -494,56 +503,67 @@ bool FFmpegCapture::play_video(const string &pathname)
 			if (last_pts == 0 && pts_origin == 0) {
 				pts_origin = frame->pts;	
 			}
-			next_frame_start = compute_frame_start(frame->pts, pts_origin, video_timebase, start, rate);
-			if (first_frame && last_frame_was_connected) {
-				// If reconnect took more than one second, this is probably a live feed,
-				// and we should reset the resampler. (Or the rate is really, really low,
-				// in which case a reset on the first frame is fine anyway.)
-				if (duration<double>(next_frame_start - last_frame).count() >= 1.0) {
-					last_frame_was_connected = false;
+			steady_clock::time_point now = steady_clock::now();
+			if (play_as_fast_as_possible) {
+				video_frame->received_timestamp = now;
+				audio_frame->received_timestamp = now;
+				next_frame_start = now;
+			} else {
+				next_frame_start = compute_frame_start(frame->pts, pts_origin, video_timebase, start, rate);
+				if (first_frame && last_frame_was_connected) {
+					// If reconnect took more than one second, this is probably a live feed,
+					// and we should reset the resampler. (Or the rate is really, really low,
+					// in which case a reset on the first frame is fine anyway.)
+					if (duration<double>(next_frame_start - last_frame).count() >= 1.0) {
+						last_frame_was_connected = false;
+					}
+				}
+				video_frame->received_timestamp = next_frame_start;
+
+				// The easiest way to get all the rate conversions etc. right is to move the
+				// audio PTS into the video PTS timebase and go from there. (We'll get some
+				// rounding issues, but they should not be a big problem.)
+				int64_t audio_pts_as_video_pts = av_rescale_q(audio_pts, audio_timebase, video_timebase);
+				audio_frame->received_timestamp = compute_frame_start(audio_pts_as_video_pts, pts_origin, video_timebase, start, rate);
+
+				if (audio_frame->len != 0) {
+					// The received timestamps in Nageru are measured after we've just received the frame.
+					// However, pts (especially audio pts) is at the _beginning_ of the frame.
+					// If we have locked audio, the distinction doesn't really matter, as pts is
+					// on a relative scale and a fixed offset is fine. But if we don't, we will have
+					// a different number of samples each time, which will cause huge audio jitter
+					// and throw off the resampler.
+					//
+					// In a sense, we should have compensated by adding the frame and audio lengths
+					// to video_frame->received_timestamp and audio_frame->received_timestamp respectively,
+					// but that would mean extra waiting in sleep_until(). All we need is that they
+					// are correct relative to each other, though (and to the other frames we send),
+					// so just align the end of the audio frame, and we're fine.
+					size_t num_samples = (audio_frame->len * 8) / audio_format.bits_per_sample / audio_format.num_channels;
+					double offset = double(num_samples) / OUTPUT_FREQUENCY -
+						double(video_format.frame_rate_den) / video_format.frame_rate_nom;
+					audio_frame->received_timestamp += duration_cast<steady_clock::duration>(duration<double>(offset));
+				}
+
+				if (duration<double>(now - next_frame_start).count() >= 0.1) {
+					// If we don't have enough CPU to keep up, or if we have a live stream
+					// where the initial origin was somehow wrong, we could be behind indefinitely.
+					// In particular, this will give the audio resampler problems as it tries
+					// to speed up to reduce the delay, hitting the low end of the buffer every time.
+					fprintf(stderr, "%s: Playback %.0f ms behind, resetting time scale\n",
+						pathname.c_str(),
+						1e3 * duration<double>(now - next_frame_start).count());
+					pts_origin = frame->pts;
+					start = next_frame_start = now;
+					timecode += MAX_FPS * 2 + 1;
 				}
 			}
-			video_frame->received_timestamp = next_frame_start;
-
-			// The easiest way to get all the rate conversions etc. right is to move the
-			// audio PTS into the video PTS timebase and go from there. (We'll get some
-			// rounding issues, but they should not be a big problem.)
-			int64_t audio_pts_as_video_pts = av_rescale_q(audio_pts, audio_timebase, video_timebase);
-			audio_frame->received_timestamp = compute_frame_start(audio_pts_as_video_pts, pts_origin, video_timebase, start, rate);
-
-			if (audio_frame->len != 0) {
-				// The received timestamps in Nageru are measured after we've just received the frame.
-				// However, pts (especially audio pts) is at the _beginning_ of the frame.
-				// If we have locked audio, the distinction doesn't really matter, as pts is
-				// on a relative scale and a fixed offset is fine. But if we don't, we will have
-				// a different number of samples each time, which will cause huge audio jitter
-				// and throw off the resampler.
-				//
-				// In a sense, we should have compensated by adding the frame and audio lengths
-				// to video_frame->received_timestamp and audio_frame->received_timestamp respectively,
-				// but that would mean extra waiting in sleep_until(). All we need is that they
-				// are correct relative to each other, though (and to the other frames we send),
-				// so just align the end of the audio frame, and we're fine.
-				size_t num_samples = (audio_frame->len * 8) / audio_format.bits_per_sample / audio_format.num_channels;
-				double offset = double(num_samples) / OUTPUT_FREQUENCY -
-					double(video_format.frame_rate_den) / video_format.frame_rate_nom;
-				audio_frame->received_timestamp += duration_cast<steady_clock::duration>(duration<double>(offset));
+			bool finished_wakeup;
+			if (play_as_fast_as_possible) {
+				finished_wakeup = !producer_thread_should_quit.should_quit();
+			} else {
+				finished_wakeup = producer_thread_should_quit.sleep_until(next_frame_start);
 			}
-
-			steady_clock::time_point now = steady_clock::now();
-			if (duration<double>(now - next_frame_start).count() >= 0.1) {
-				// If we don't have enough CPU to keep up, or if we have a live stream
-				// where the initial origin was somehow wrong, we could be behind indefinitely.
-				// In particular, this will give the audio resampler problems as it tries
-				// to speed up to reduce the delay, hitting the low end of the buffer every time.
-				fprintf(stderr, "%s: Playback %.0f ms behind, resetting time scale\n",
-					pathname.c_str(),
-					1e3 * duration<double>(now - next_frame_start).count());
-				pts_origin = frame->pts;
-				start = next_frame_start = now;
-				timecode += MAX_FPS * 2 + 1;
-			}
-			bool finished_wakeup = producer_thread_should_quit.sleep_until(next_frame_start);
 			if (finished_wakeup) {
 				if (audio_frame->len > 0) {
 					assert(audio_pts != -1);
@@ -627,6 +647,7 @@ bool FFmpegCapture::process_queued_commands(AVFormatContext *format_ctx, const s
 			start = compute_frame_start(last_pts, pts_origin, video_timebase, start, rate);
 			pts_origin = last_pts;
 			rate = cmd.new_rate;
+			play_as_fast_as_possible = (rate >= 10.0);
 			break;
 		}
 	}
